text property
A text to describe that there is a pending async validation.
If null, built-in default message is shown.
Implementation
final String? text;
A text to describe that there is a pending async validation.
If null, built-in default message is shown.
final String? text;