height property
A height of this control.
If null, subtitle1 text theme's height will be used.
If the theme is not found, 16 is used.
The intent of the default value is that it should be aligned to default
height of FormTextField, so the logic to determine default height
subject to change in future.
If you want to stabilize the height, specify this value explicitly.
Implementation
final double? height;